@@ -16,26 +16,23 @@ warnings.filterwarnings('ignore')
 class TestSphtFunc(unittest.TestCase):
 
     def setUp(self):
+        self.lmax = 64
         self.path = os.path.dirname( os.path.realpath( __file__ ) )
-        try:
-            self.map1 = [hp.ma(m) for m in hp.read_map(os.path.join(self.path, 'data', 'wmap_band_iqumap_r9_7yr_W_v4.fits'), (0,1,2))]
-            self.map2 = [hp.ma(m) for m in hp.read_map(os.path.join(self.path, 'data', 'wmap_band_iqumap_r9_7yr_V_v4.fits'), (0,1,2))]
-            self.mask = hp.read_map(os.path.join(self.path, 'data', 'wmap_temperature_analysis_mask_r9_7yr_v4.fits')).astype(np.bool)
-        except:
-            warnings.warn("""Missing Wmap test maps from the data folder, please download them from Lambda and copy them in the test/data folder:
-            http://lambda.gsfc.nasa.gov/data/map/dr4/skymaps/7yr/raw/wmap_band_iqumap_r9_7yr_W_v4.fits
-            http://lambda.gsfc.nasa.gov/data/map/dr4/skymaps/7yr/raw/wmap_band_iqumap_r9_7yr_V_v4.fits
-            http://lambda.gsfc.nasa.gov/data/map/dr4/ancillary/masks/wmap_temperature_analysis_mask_r9_7yr_v4.fits
-            on Mac or Linux you can run the bash script get_wmap_maps.sh from the same folder
-            """)
-            raise
+        self.map1 = [hp.ma(m) for m in hp.read_map(os.path.join(self.path, 'data', 'wmap_band_iqumap_r9_7yr_W_v4_udgraded32.fits'), (0,1,2))]
+        self.map2 = [hp.ma(m) for m in hp.read_map(os.path.join(self.path, 'data', 'wmap_band_iqumap_r9_7yr_V_v4_udgraded32.fits'), (0,1,2))]
+        self.mask = hp.read_map(os.path.join(self.path, 'data', 'wmap_temperature_analysis_mask_r9_7yr_v4_udgraded32.fits')).astype(np.bool)
         for m in chain(self.map1, self.map2):
             m.mask = np.logical_not(self.mask)
-        self.cla = hp.read_cl(os.path.join(self.path, 'data', 'cl_wmap_fortran.fits'))
-        cls = pyfits.open(os.path.join(self.path, 'data',
-                                       'cl_iqu_wmap_fortran.fits'))[1].data
+        self.cla = hp.read_cl(os.path.join(self.path, 'data', 'cl_wmap_band_iqumap_r9_7yr_W_v4_udgraded32_II_lmax64_rmmono_3iter.fits'))
+        self.cl_fortran_nomask = hp.read_cl(os.path.join(self.path, 'data', 'cl_wmap_band_iqumap_r9_7yr_W_v4_udgraded32_II_lmax64_rmmono_3iter_nomask.fits'))
+        cls_file = pyfits.open(os.path.join(self.path, 'data',
+                                       'cl_wmap_band_iqumap_r9_7yr_W_v4_udgraded32_IQU_lmax64_rmmono_3iter.fits'))
+        # fix for pyfits to read the file with duplicate column names
+        for i in range(2, 6):
+            cls_file[1].header['TTYPE%d' % i] += '-%d' % i
+        cls = cls_file[1].data
         # order of HEALPIX is TB, EB while in healpy is EB, TB
-        self.cliqu = [cls.field(i) for i in (0,1,2,3,5,4)]
+        self.cliqu = [np.array(cls.field(i)) for i in (0,1,2,3,5,4)]
         nside = 32
         lmax = 64
         fwhm_deg = 7.
@@ -45,21 +42,26 @@ class TestSphtFunc(unittest.TestCase):
                                  fwhm=np.radians(fwhm_deg), new=False)
 
     def test_anafast(self):
-        cl = hp.anafast(self.map1[0].filled(), lmax = 1024)
-        self.assertEqual(len(cl), 1025)
+        cl = hp.anafast(self.map1[0].filled(), lmax = self.lmax)
+        self.assertEqual(len(cl), 65)
         np.testing.assert_array_almost_equal(cl, self.cla, decimal=8)
 
+    def test_anafast_nomask(self):
+        cl = hp.anafast(self.map1[0].data, lmax = self.lmax)
+        self.assertEqual(len(cl), 65)
+        np.testing.assert_array_almost_equal(cl, self.cl_fortran_nomask, decimal=8)
+
     def test_anafast_iqu(self):
-        cl = hp.anafast([m.filled() for m in self.map1], lmax = 1024)
-        self.assertEqual(len(cl[0]), 1025)
+        cl = hp.anafast(self.map1, regression=True, lmax = self.lmax)
+        self.assertEqual(len(cl[0]), 65)
         self.assertEqual(len(cl), 6)
         for i in range(6):
             np.testing.assert_array_almost_equal(cl[i], self.cliqu[i], decimal=8)
 
     def test_anafast_xspectra(self):
-        cl = hp.anafast(self.map1[0].filled(), self.map2[0].filled(), lmax = 1024)
-        self.assertEqual(len(cl), 1025)
-        clx = hp.read_cl(os.path.join(self.path, 'data', 'clx.fits'))
+        cl = hp.anafast(self.map1[0], self.map2[0], lmax = self.lmax, regression=True)
+        self.assertEqual(len(cl), self.lmax+1)
+        clx = hp.read_cl(os.path.join(self.path, 'data', 'cl_wmap_band_iqumap_r9_7yr_WVxspec_v4_udgraded32_II_lmax64_rmmono_3iter.fits'))
         np.testing.assert_array_almost_equal(cl, clx, decimal=8)
 
     def test_synfast(self):
@@ -69,24 +71,28 @@ class TestSphtFunc(unittest.TestCase):
         seed = 12345
         np.random.seed(seed)
         map_pregen = hp.read_map(os.path.join(self.path, 'data',
-                                              'map_pregen_seed%d.fits' % seed))
-        sim_map = hp.synfast(self.cla, nside, lmax = lmax, pixwin=False,
-                             fwhm=np.radians(fwhm_deg), new=False, pol=False)
+                                              'map_synfast_seed%d.fits' % seed),
+                                              (0,1,2))
+        sim_map = hp.synfast(self.cliqu, nside, lmax = lmax, pixwin=False,
+                             fwhm=np.radians(fwhm_deg), new=False, pol=True)
         np.testing.assert_array_almost_equal(sim_map, map_pregen,
                                              decimal=8)
 
-    def test_smoothing(self):
-        smoothed = hp.ud_grade(hp.smoothing(self.map1[0].data, fwhm=np.radians(1), lmax=1024), 32)
+    def test_smoothing_notmasked(self):
+        smoothed = hp.smoothing([m.data for m in self.map1], fwhm=np.radians(10), lmax=self.lmax, regression=False)
         smoothed_f90 = hp.read_map(os.path.join(self.path, 'data',
-                  'wmap_band_imap_r9_7yr_W_v4_1deg_nside32.fits'))
-        np.testing.assert_array_almost_equal(smoothed, smoothed_f90)
+                  'wmap_band_iqumap_r9_7yr_W_v4_udgraded32_smoothed10deg_fortran.fits'), (0,1,2))
+        np.testing.assert_array_almost_equal(smoothed, smoothed_f90, decimal=6)
 
     def test_smoothing_masked(self):
-        smoothed = hp.ud_grade(hp.smoothing(self.map1[0], fwhm=np.radians(1), lmax=1024), 32)
+        smoothed = hp.smoothing(self.map1, fwhm=np.radians(10), lmax=self.lmax, regression=False)
         smoothed_f90 = hp.ma(hp.read_map(os.path.join(self.path, 'data',
-                  'wmap_band_imap_r9_7yr_W_v4_1deg_nside32_masked.fits')))
-        np.testing.assert_array_almost_equal(smoothed.filled(), smoothed_f90.filled())
-        np.testing.assert_array_almost_equal(smoothed, smoothed_f90)
+                  'wmap_band_iqumap_r9_7yr_W_v4_udgraded32_masked_smoothed10deg_fortran.fits'), (0,1,2)))
+        # fortran does not restore the mask
+        for mm in smoothed_f90:
+            mm.mask = smoothed[0].mask
+        for i in range(3):
+            np.testing.assert_array_almost_equal(smoothed[i].filled(), smoothed_f90[i].filled(), decimal=6)
         
     def test_gauss_beam(self):
         idl_gauss_beam = np.array(pyfits.open(os.path.join(self.path, 'data', 'gaussbeam_10arcmin_lmax512_pol.fits'))[0].data).T
